@@ -70,11 +70,6 @@ namespace LongoMatch.Gui
 			
 			projectType = ProjectType.None;
 
-			if (Environment.OSVersion.Platform == PlatformID.Win32NT) {
-				DrawingToolAction.Visible = false;
-				DrawingToolAction.DisconnectAccelerator();
-			}
-
 			eManager = new EventsManager(treewidget1,
 			                             localplayerslisttreewidget,
 			                             visitorplayerslisttreewidget,
@@ -111,73 +106,71 @@ namespace LongoMatch.Gui
 		
 		#region Private Methods
 		private void SetProject(Project project, ProjectType projectType) {
+			if (project == null)
+				return;
+			
 			CloseOpenedProject(true);
 			openedProject = project;
 			this.projectType = projectType;
 			eManager.OpenedProject = project;
 			eManager.OpenedProjectType = projectType;
-			if (project!=null) {
-				if (projectType == ProjectType.FileProject){
-					// Check if the file associated to the project exists
-					if (!File.Exists(project.File.FilePath)) {
-						MessagePopup.PopupMessage(this, MessageType.Warning,
-						                          Catalog.GetString("The file associated to this project doesn't exist.")+"\n"
-						                          +Catalog.GetString("If the location of the file has changed try to edit it with the database manager."));
-						CloseOpenedProject(true);
-					} else {
-						Title = System.IO.Path.GetFileNameWithoutExtension(project.File.FilePath) + " - LongoMatch";
-						try {
-							playerbin1.Open(project.File.FilePath);							
-						}
-						catch (GLib.GException ex) {
-							MessagePopup.PopupMessage(this, MessageType.Error,
-							                          Catalog.GetString("An error occurred opening this project:")+"\n"+ex.Message);
-							CloseOpenedProject(true);
-							return;
-						}
-						if (project.File.HasVideo)
-							playerbin1.LogoMode = true;
-						else
-							playerbin1.LogoMode = false;							
-						if (project.File.HasVideo)
-							playerbin1.LogoMode = false;
-						timelinewidget1.Project = project;
-						treewidget1.ProjectIsLive = false;
-						localplayerslisttreewidget.ProjectIsLive = false;
-						visitorplayerslisttreewidget.ProjectIsLive = false;
-						tagstreewidget1.ProjectIsLive = false;						
-					} 
-				}else {
-					Title = "LongoMatch";
-					playerbin1.Visible = false;					
-					capturerBin = new CapturerBin();
-					capturerBin.Logo = System.IO.Path.Combine(MainClass.ImagesDir(),"background.png");
-					capturerBin.CaptureFinished += delegate {
-						CloseOpenedProject(true);	
-					};
-					eManager.Capturer = capturerBin;
-					hbox2.Add(capturerBin);
-					(capturerBin).Show();	
-					treewidget1.ProjectIsLive = true;
-					localplayerslisttreewidget.ProjectIsLive = true;
-					visitorplayerslisttreewidget.ProjectIsLive = true;
-					tagstreewidget1.ProjectIsLive = true;	
-					CaptureModeAction.Active = true;
-				}
-				
-				playlistwidget2.Stop();
-				treewidget1.Project=project;
-				localplayerslisttreewidget.SetTeam(project.LocalTeamTemplate,project.GetLocalTeamModel());
-				visitorplayerslisttreewidget.SetTeam(project.VisitorTeamTemplate,project.GetVisitorTeamModel());
-				tagstreewidget1.Project = project;				
-				buttonswidget1.Sections = project.Sections;
-				MakeActionsSensitive(true,projectType);
-				ShowWidgets();
-				hkManager.Sections=project.Sections;
-				KeyPressEvent += hotkeysListener;
-			}
+			
+			if (projectType == ProjectType.FileProject){
+				// Check if the file associated to the project exists
+				if (!File.Exists(project.File.FilePath)) {
+					MessagePopup.PopupMessage(this, MessageType.Warning,
+					                          Catalog.GetString("The file associated to this project doesn't exist.")+"\n"
+					                          +Catalog.GetString("If the location of the file has changed try to edit it with the database manager."));
+					CloseOpenedProject(false);
+					return;
+				} else {
+					Title = System.IO.Path.GetFileNameWithoutExtension(project.File.FilePath) + " - LongoMatch";
+					try {
+						playerbin1.Open(project.File.FilePath);							
+					}
+					catch (GLib.GException ex) {
+						MessagePopup.PopupMessage(this, MessageType.Error,
+						                          Catalog.GetString("An error occurred opening this project:")+"\n"+ex.Message);
+						CloseOpenedProject(false);
+						return;
+					}
+					playerbin1.LogoMode = false;
+					timelinewidget1.Project = project;
+					treewidget1.ProjectIsLive = false;
+					localplayerslisttreewidget.ProjectIsLive = false;
+					visitorplayerslisttreewidget.ProjectIsLive = false;
+					tagstreewidget1.ProjectIsLive = false;						
+				} 
+			}else {
+				Title = "LongoMatch";
+				playerbin1.Visible = false;					
+				capturerBin = new CapturerBin();
+				capturerBin.Logo = System.IO.Path.Combine(MainClass.ImagesDir(),"background.png");
+				capturerBin.CaptureFinished += delegate {
+					CloseOpenedProject(true);	
+				};
+				eManager.Capturer = capturerBin;
+				hbox2.Add(capturerBin);
+				(capturerBin).Show();	
+				treewidget1.ProjectIsLive = true;
+				localplayerslisttreewidget.ProjectIsLive = true;
+				visitorplayerslisttreewidget.ProjectIsLive = true;
+				tagstreewidget1.ProjectIsLive = true;	
+				CaptureModeAction.Active = true;
+			}	
+			
+			playlistwidget2.Stop();
+			treewidget1.Project=project;
+			localplayerslisttreewidget.SetTeam(project.LocalTeamTemplate,project.GetLocalTeamModel());
+			visitorplayerslisttreewidget.SetTeam(project.VisitorTeamTemplate,project.GetVisitorTeamModel());
+			tagstreewidget1.Project = project;				
+			buttonswidget1.Sections = project.Sections;
+			MakeActionsSensitive(true,projectType);
+			ShowWidgets();
+			hkManager.Sections=project.Sections;
+			KeyPressEvent += hotkeysListener;			
 		}
-
+		
 		private void CloseOpenedProject(bool save) {
 			bool playlistVisible = playlistwidget2.Visible;			
 			
@@ -477,20 +470,28 @@ namespace LongoMatch.Gui
 
 		protected override bool OnKeyPressEvent(EventKey evnt)
 		{
-			if (openedProject != null && evnt.State == ModifierType.None) {
-				Gdk.Key key = evnt.Key;
+			Gdk.Key key = evnt.Key;
+			Gdk.ModifierType modifier = evnt.State;
+			bool ret;
+			
+			ret = base.OnKeyPressEvent(evnt);
+
+			if (openedProject == null)
+				return ret;
+			
+			if (projectType == ProjectType.FileProject){
 				switch (key){
-					case Constants.PREV_FRAME:
-						playerbin1.SeekToPreviousFrame(selectedTimeNode != null);
+					case Constants.SEEK_FORWARD:
+						if (modifier == Constants.STEP)
+							playerbin1.StepForward();
+						else 
+							playerbin1.SeekToNextFrame(selectedTimeNode != null);						
 						break;
-					case Constants.NEXT_FRAME:
-						playerbin1.SeekToNextFrame(selectedTimeNode != null);
-						break;
-					case Constants.STEP_FORWARD:
-						playerbin1.StepForward();
-						break;
-					case Constants.STEP_BACKWARD:
-						playerbin1.StepBackward();
+					case Constants.SEEK_BACKWARD:
+						if (modifier == Constants.STEP)
+							playerbin1.StepBackward();
+						else 
+							playerbin1.SeekToPreviousFrame(selectedTimeNode != null);						
 						break;
 					case Constants.FRAMERATE_UP:
 						playerbin1.FramerateUp();
@@ -501,9 +502,15 @@ namespace LongoMatch.Gui
 					case Constants.TOGGLE_PLAY:
 						playerbin1.TogglePlay();
 						break;			
-				}					
+				}	
+			} else {
+				switch (key){
+					case Constants.TOGGLE_PLAY:
+						capturerBin.ToggleCapture();
+						break;			
+				}	
 			}
-			return base.OnKeyPressEvent(evnt);
+			return ret;
 		}
 
 		protected virtual void OnTimeNodeSelected(LongoMatch.TimeNodes.MediaTimeNode tNode)
@@ -530,14 +537,13 @@ namespace LongoMatch.Gui
 			drawingtoolbox1.Visible = DrawingToolAction.Active;
 			drawingtoolbox1.DrawingVisibility = DrawingToolAction.Active;
 		}
-
+	
 		protected override bool OnDeleteEvent (Gdk.Event evnt)
 		{
 			CloseAndQuit();	
 			return true;
 		}
-
 		#endregion	
-		}
+		
 	}
 }
\ No newline at end of file
